
--- Show a health frame that tracks CID, GUID or UID for its health status.
-- @param	id	numbe|string The creature ID, global unique ID or Uint ID to track.
-- @optional	anchorID	string	The name of the anchor where the frame should show up. If said anchor does not exist the default one will be used.
-- @optional	markers		table	This table sets the markers on the bar, each marker in the table should be a number between 0-100 representing the percentage.
-- @optional	icon		string	Texture path to the icon to use, overrides 3D-model and unit texture.
-- @usage RW.Callbacks:Fire("MPBHealthByID", "0xF130007F1E002489", nil, {75, 25})
function MPBHealthByID(event, id, anchorID, markers, icon)
end

--- Show a power farme that tracks CID, GUID or UID for its power status.
-- @param	id	numbe|string The creature ID, global unique ID or Uint ID to track.
-- @optional	anchorID	string	The name of the anchor where the frame should show up. If said anchor does not exist the default one will be used.
-- @optional	markers		table	This table sets the markers on the bar, each marker in the table should be a number between 0-100 representing the percentage.
-- @optional	icon		string	Texture path to the icon to use, overrides 3D-model and unit texture.
-- @usage RW.Callbacks:Fire("MPBPowerByID", "boss1", nil, {75, 25})
function MPBPowerByID(event, id, anchorID, markers, icon)
end

--- Hide a health frame by ID.
-- @param	id	number|string	The CID, GUID or UID to the frame to hide.
-- @usage RW.Callbacks:Fire("MPBHealthHideByID", "0xF130007F1E002489")
function MPBHealthHideByID(event, id)
end

--- ide a power frame by ID.
-- @param	id	number|string	The CID, GUID or UID to the frame to hide.
-- @usage RW.Callbacks:Fire("MPBPowerHideByID", "boss1")
function MPBPowerHideByID(event, id)
end

--- Show a frame that tracks stacks by Aura.
-- @param	id	numbe|string The creature ID, global unique ID or Uint ID to track.
-- @param	spell	number	The spell to track stacks for.
-- @param	maxStacks	number	The number of maximum stacks this spell can have, used for presentation.
-- @optional	anchorID	string	The anchor that the frame should show up on, The default one will be selected if none passed or if not found.
-- @optional	buffType	string	"HARMFULL" or "HELPFULL". "HARMFULL" is the default if non passed.
-- @optional	markers		table	This table sets the markers on the bar, each marker in the table should be a number between 0-100 representing the percentage.
-- @optional	icon		string	Texture path to the icon to use, if none passed the icon for the spell will be used.
-- @usage RW.Callbacks:Fire("MPBSpellStackAura", "boss1", 22455, 10, nil, "HARMFULL")
function MPBSpellStackAura(event, id, spell, maxStacks, anchorID, buffType, markers, icon)
end

--- Show  frame that tracks stacks by monitoring the combat log.
-- @param	id	numbe|string The creature ID, global unique ID or Uint ID to track.
-- @param	spells	number|table	The spell(s) to track stacks for. Pass several if its can be different spell IDs for the same spell (heroic and normal mode spells).
-- @optional	anchorID	string	The anchor that the frame should show up on, The default one will be selected if none passed or if not found.
-- @optional	markers		table	This table sets the markers on the bar, each marker in the table should be a number between 0-100 representing the percentage.
-- @optional	icon		string	Texture path to the icon to use, if none passed the icon for the spell will be used.
-- @usage	RW.Callbacks:Fire("MPBSpellStackCombat", "boss1", {24255, 24256}, 10, nil, {20, 80})
function MPBSpellStackCombat(event, id, spells, maxStacks, anchorID, markers, icon)
end

--- Hide a frame that is tracking spell stacks by aura or combat log.
-- @param	id	number|string	The CID, GUID or UID to the frame to hide.
-- @usage	RW.Callbacks:Fire("MPBSpellStackHide", "boss1")
function MPBSpellStackHide(event, id)
end

--- Show a frame that is updated from an external function.
-- @param	id	string	A unique ID for the bar to interact with it later.
-- @param	func	function	The function that returns the values, the function must return: current, max, name. Where name is the name showing up on the frame.
-- @optional	anchorID	string	The anchor that the frame should show up on, The default one will be selected if none passed or if not found.
-- @optional	markers		table	This table sets the markers on the bar, each marker in the table should be a number between 0-100 representing the percentage.
-- @optional	icon		string	Texture path to the icon to use, if none passed, no icon will be shown.
-- @usage RW.Callbacks:Fire("MPBExternal", "SomeUpdater", function() return currentStacks, maxStacks, "Spell of Doom!" end, nil, nil, select(3, GetSpellInfo(35356)))
function MPBExternal(event, id, func, anchorID, markers, icon)
end

--- Hide a frame that is updated from external function.
-- @param	id	string	The unique ID set when showing the frame.
-- @usage RW.Callbacks:Fire("MPBExternalHide", "SomeUpdater")
function MPBExternalHide(event, id)
end