local mod = RW:Boss("Halion", "The Ruby Sanctum")
local L

mod.BossIcon = [[Interface\Icons\Achievement_Boss_Keristrasza]]
mod.SupressGlobalHealthFrames = true


---------------------------
-- Variables

-- Fiery Combustion
local wFireCon, mFireCon, tFireConCD, iFireCon

-- Soul Consumption
local wShadowCon, mShadowCon, tShadowConCD, iShadowCon

-- Twilight Cutter
local wCutter, tCutterCD, tCutterDur

-- Meteor Strike
local wMeteor, tMeteorCD, tMetorImpact

-- Dark Breath
local wDarkBreath, tDarkBreathCD

-- Flame Breath
local wFlameBreath, tFlameBreathCD

local mPhase
local tBerserk

local corpName, _, corpIcon = GetSpellInfo(74826)

---------------------------
-- Init

function mod:OnRegister()
	L = mod:RegisterLocale(self:GetName(), "enUS", true)
	if L then		
		L.twilightcutter_emote	= "The orbiting spheres pulse with dark energy!"
		L.meteor_emote			= "The heavens burn!"
		
		L.phase2_emote	= "You will find only suffering within the realm of twilight! Enter if you dare!"
		L.phase3_emote  = "I am the light and the darkness! Cower, mortals, before the herald of Deathwing!"
		
		L.show_croporeality_frane = "Corporeality status frame"
	end
	L = mod:GetLocale()
	self.L = L
	
	self:SetTrigger(39863)
	self:SetWin()
	
	self:AddBoolOption("CorporealityFrame", L.show_croporeality_frane, nil, true, select(3, GetSpellInfo(74826)))
		
	tBerserk			= self:BerserkTimer(480)

	-- Fiery Combustion
	tFireConCD			= mod:CDTimer(25, 74562)
	wFireCon			= mod:RunawayWarning(74562)
	mFireCon			= mod:TargetMessage(74562)
	iFireCon			= mod:Icon("SKULL", 74562, false, 30)
	
	-- Soul Consumption
	tShadowConCD		= mod:CDTimer(25, 74792)
	wShadowCon			= mod:RunawayWarning(74792)
	mShadowCon			= mod:TargetMessage(74792)
	iShadowCon			= mod:Icon("CROSS", 74792, false, 30)
	
	-- Twilight Cutter
	wCutter				= mod:CastWarning(77846)
	tCutterCD			= mod:CDTimer(15, 77846)
	tCutterDur			= mod:DurTimer(10, 77846)
	
	-- Meteor Strike
	tMeteorCD			= mod:CDTimer(40, 74648)
	tMetorImpact		= mod:CastTimer(7.5, 74648)
	wMeteor				= mod:CastWarning(74648)
	
	-- Dark Breath
	wDarkBreath			= mod:CastWarning(75954, nil, nil, false)
	tDarkBreathCD		= mod:CDTimer(12, 75954, nil, nil, false)
	
	-- Flame Breath
	wFlameBreath		= mod:CastWarning(74526, nil, nil, false)
	tFlameBreathCD		= mod:CDTimer(12, 74526, nil, nil, false)
	
	mPhase				= mod:PhaseMessage()
end

---------------------------
-- Locals
local function UpdateCorporeality()
	local text = select(3, GetWorldStateUIInfo(1))
	if not text then return 50, 100, corpName end
	local percent = text:match("(%d)")
	if percent then
		return percent * 10, 100, corpName
	end
	return 50, 100, corpName
end

---------------------------
-- Start

function mod:OnEngage(trigger)
	self:Track("FieryConsumption", 74562)
	self:Track("SoulConsumtpion", 74792)
	self:Track("DarkBreath", 75954, 74806, 75955, 75956)
	self:Track("FlameBreath", 74526, 74525, 74527, 74528)
	
	self:YellTrack("TwilightCutter", L.twilightcutter_emote)
	self:YellTrack("Phase2", L.phase2_emote)
	self:YellTrack("Phase3", L.phase3_emote)
	self:YellTrack("MeteorYell", L.meteor_emote)
	
	tMeteorCD:Start(30)
	tFireConCD:Start(17)
	tFlameBreathCD:Start(5.5)
	tBerserk:Start()
	
	RW.Callbacks:Fire("MPBHealthByID", 39863, nil, {75, 50})
end

function mod:OnEnd(wipe, trigger)
	RW.Callbacks:Fire("MPBExternalHide", "HalionCorp")
end

function mod:FieryConsumption(event, args)
	if event == "SPELL_AURA_APPLIED" then
		if args:IsPlayer() then
			wFireCon:Show()
			SendChatMessage("Fiery Combustion on "..self.pName.."!", "SAY")
		end
		mFireCon:Show(args.dName)		
		iFireCon:Show(args.dName)
		
	elseif event == "SPELL_CAST_SUCCESS" then
		if self:IsHeroic() then
			tFireConCD:Start(20)
		else
			tFireConCD:Start()
		end
	
	elseif event == "SPELL_AURA_REMOVED" then
		iFireCon:Hide(args.dName)
	end
end

function mod:SoulConsumtpion(event, args)
	if event == "SPELL_AURA_APPLIED" then
		if args:IsPlayer() then
			wShadowCon:Show()
			SendChatMessage("Soul Consumption on "..self.pName.."!", "SAY")
		end
		mShadowCon:Show(args.dName)		
		iShadowCon:Show(args.dName)
		
	elseif event == "SPELL_CAST_SUCCESS" then
		if self:IsHeroic() then
			tShadowConCD:Start(20)
		else
			tShadowConCD:Start()
		end
	
	elseif event == "SPELL_AURA_REMOVED" then
		iShadowCon:Hide(args.dName)
	end
end

function mod:DarkBreath(event, args)
	if event == "SPELL_CAST_START" then
		wDarkBreath:Show()
		tDarkBreathCD:Start()
	end
end

function mod:FlameBreath(event, args)
	if event == "SPELL_CAST_START" then
		wFlameBreath:Show()
		tFlameBreathCD:Start()
	end
end

function mod:TwilightCutter(event, msg, name)
	wCutter:Show()
	tCutterDur:Schedule(5)
	tCutterCD:Schedule(15)
	self:SendSync("CutterYell")
end

function mod:MeteorYell(event, msg, name)
	tMetorImpact:Start()
	wMeteor:Show()
	tMetorImpact:Start()
	tMeteorCD:Start()
	self:SendSync("MeteorYell")
	RW.Callbacks:Fire("MPBHealthHideByID", 40142)
	RW.Callbacks:Fire("MPBHealthByID", 39863, nil, {75, 50})
end

function mod:Phase2(event, msg, name)
	mPhase:Show(2)
	if self:IsHeroic() then	
		tCutterCD:Start(35)
	else
		tCutterCD:Start(40)
	end
	tMeteorCD:Stop()
	tFlameBreathCD:Stop()
	tFireConCD:Stop()
	RW.Callbacks:Fire("MPBHealthHideByID", 39863)
	RW.Callbacks:Fire("MPBHealthByID", 40142, nil, {75, 50})
end

function mod:Phase3(event, msg, name)
	mPhase:Show(3)
	if self.db.profile.CorporealityFrame then
		RW.Callbacks:Fire("MPBExternal", "HalionCorp", UpdateCorporeality, nil, {40, 60}, corpIcon)
	end
end

function mod:OnSync(sender, msg, data, ...)
	if msg == "CutterYell" then
		tCutterDur:Schedule(5)
		tCutterCD:Schedule(15)

	elseif msg == "MeteorYell" then
		tMetorImpact:Start()
		tMeteorCD:Start()
	end
end
